from setuptools import setup
import re

requirements = [
    'requests',
]

version = ''
with open('marblex/__init__.py') as f:
    version = re.search(r'^__version__\s*=\s*[\'"]([^\'"]*)[\'"]', f.read(), re.MULTILINE).group(1)

if not version:
    raise RuntimeError('version is not set')

readme = ''
with open('README.md') as f:
    readme = f.read()

setup(
    name='marblex.py',
    author='xStacia',
    url='https://github.com/staciax/marblex.py',
    project_urls={
        "Issue tracker": "https://github.com/staciax/marblex.py/issues",
    },
    version=version,
    packages=['marblex'],
    license='MIT',
    description='A library to get various cryptocurrency prices from the marblex API',
    long_description=readme,
    install_requires=requirements,
    python_requires='>=3.8.0',
    classifiers=[
        'License :: OSI Approved :: MIT License',
        'Intended Audience :: Developers',
        'Natural Language :: English',
        'Operating System :: OS Independent',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.8',
        'Programming Language :: Python :: 3.9',
        'Programming Language :: Python :: 3.10',
        'Programming Language :: Python :: 3.11',
        'Topic :: Internet :: WWW/HTTP',
    ]
)



from __future__ import annotations

import logging
from .http import HTTPClient
from .models import *

from typing import Optional

_log = logging.getLogger(__name__)

__all__ = ('Client', 'Marblex')

class Client:

    """ Marblex API Wrapper Client """

    def __init__(self):
        self._http = HTTPClient()
        self._nkt_percent: str = ''
        self._nka_percent: str = ''

    def get_NKA(self) -> Optional[Coin]:
        """ Return the NKA Coin. """
        data = self._http.fetch_NKA()
        if data is None:
            return None
        return Coin(client=self, data=data)

    def get_NKT(self) -> Optional[Coin]:
        """ Return the NKT Coin. """
        data = self._http.fetch_NKT()
        if data is None:
            return None
        return Coin(client=self, data=data)

    def get_exchange(self) -> Optional[Exchange]:
        """ Return the Exchange object. """
        data = self._http.fetch_loremboard()
        if data is None:
            return None
        return Exchange(client=self, data=data)

    def close(self) -> None:
        """ Close the client. """
        self._http.close()

    def __enter__(self) -> Client:
        _log.debug('Entering context manager')
        return self

    def __exit__(self, exc_type, exc_value, traceback) -> None:
        self.close()
        return None

    def __del__(self) -> None:
        self.close()
        return None

Marblex = Client